# SPDX-FileCopyrightText : 2023 Detlef Gebhardt, written for CircuitPython
# SPDX-FileCopyrightText : Copyright (c) 2023 Detlef Gebhardt
# SPDX-Filename          : Earth-Clock
# SPDX-License-Identifier: GEBMEDIA
import time
import gc
import board
import busio
import displayio
import terminalio
from adafruit_display_text import label
from adafruit_display_shapes.roundrect import RoundRect
from adafruit_display_shapes.circle import Circle
import adafruit_imageload
from adafruit_ticks import ticks_ms
import math
import gc9a01
import my_qmi8658

# Alle verwendeten Ressourcen freigeben
displayio.release_displays()
# Display initialisieren
spi = busio.SPI(clock=board.LCD_CLK, MOSI=board.LCD_DIN)
display_bus = displayio.FourWire(spi, command=board.LCD_DC, chip_select=board.LCD_CS, reset=board.LCD_RST)
display = gc9a01.GC9A01(display_bus, width=240, height=240, backlight_pin=board.LCD_BL)
group1 = displayio.Group()
display.rotation = 90
display.brightness = 0

display.show(group1)

# Sensor initialisieren
sensor=my_qmi8658.QMI8658()

zeit = "00:00:00"
xpos = 120
ypos = 120
width = 240
height = 240
i = 0
j = -15
start = 0

image1, palette = adafruit_imageload.load(
    "/images/erde.bmp", bitmap=displayio.Bitmap, palette=displayio.Palette)
tile_grid1 = displayio.TileGrid(image1, pixel_shader=palette)
group1.append(tile_grid1)

# Rechteck mit abgerundeten Ecken
roundrect1 = RoundRect(60, 132, 120, 40, 10, fill=0x0, outline=0xffffff, stroke=3)
group1.append(roundrect1)

# Ziffernring
for i in range(1,13,1):
    updating_label = label.Label(
        font=terminalio.FONT, text=str(i), scale=2, color=0xffff00,
        line_spacing=1)
    #set label position on the display and add label
    updating_label.anchor_point = (0, 0)
    #updating_label.anchored_position = (xpos-10+int(90*math.cos(i*math.pi/6)),ypos-10-int(90*math.sin(i*math.pi/6)))
    if i<10:
        updating_label.anchored_position = (xpos-5+int(105*math.cos(-1*i*math.pi/6+ math.pi/2)),
                                        ypos-12-int(105*math.sin(-1*i*math.pi/6+ math.pi/2)))
    else:
        updating_label.anchored_position = (xpos-10+int(105*math.cos(-1*i*math.pi/6+ math.pi/2)),
                                        ypos-12-int(105*math.sin(-1*i*math.pi/6+ math.pi/2)))
    group1.append(updating_label)
    display.show(group1)

## create the label for time
updating_label1 = label.Label(
    font=terminalio.FONT, text=zeit, scale=2, color=0xffffff,
    line_spacing=1)
# set label position on the display and add label
updating_label1.anchor_point = (0, 0)
updating_label1.anchored_position = (70, 140)
group1.append(updating_label1)

# Stundenpunkt
xpos_hour = int(width/2 + 105*math.cos(j*math.pi/30))
ypos_hour = int(height/2 + 105*math.sin(j*math.pi/30))
circle_hour = Circle(xpos_hour, ypos_hour, 8, fill=0xff0000, outline=0x000000)
group1.append(circle_hour)
# Minutenpunkt
xpos_min = int(width/2 + 105*math.cos(j*math.pi/30))
ypos_min = int(height/2 + 105*math.sin(j*math.pi/30))
circle_min = Circle(xpos_min, ypos_min, 8, fill=0x00ff00, outline=0x000000 )
group1.append(circle_min)

current_time = time.localtime()
hour = current_time.tm_hour
minute = current_time.tm_min
second = current_time.tm_sec

while True:
    #read QMI8658
    reading=sensor.Read_XYZ()
    # Display wird um die y-Achse gekippt
    wert_y = (10)*reading[0]
    wert_x = (10)*reading[1]
    #print(wert_y,wert_x)
    if current_time.tm_min <= 1 and current_time.tm_hour == 0:
        if wert_y < -6 and display.brightness == 1:
        #    display.rotation = 0
            start = ticks_ms()
            if minute < 59:
                minute += 1
                time.sleep(0.6)
            else:
                minute = 0
                time.sleep(0.6)
        if wert_y > 6 and display.brightness == 1:
        #    display.rotation = 180
            start = ticks_ms()
            if hour < 24:
                hour += 1
                time.sleep(0.6)
            else:
                hour = 0
                time.sleep(0.6)
    if wert_y >= -6 and wert_y <= 6 and wert_x < -6:
        display.rotation = 90
        display.brightness = 1
        start = ticks_ms()    
    if wert_y >= -6 and wert_y <= 6 and wert_x > 6:
        display.rotation = 270
        display.brightness = 1
        start = ticks_ms()
    # Display nach 5 sec abschalten
    if (ticks_ms() - start)/ 1000 > 5:
        display.brightness = 0
        start = 0
    
    # Sekunden zaehlen
    current_time = time.localtime()
    second = current_time.tm_sec
    if second == 59:
        minute += 1
        if minute == 60:
            minute = 0
            hour += 1
            if hour == 24:
                hour = 0
        time.sleep(1)
    #
    # Zeitstring zur Anzeige aufbereiten
    # 
    zeit = str(hour) + ":" + str(minute) + ":" + str(second)
    if second < 10:
        zeit = str(hour) + ":" + str(minute) + ":" + "0" + str(second)
    if minute < 10:
        zeit = str(hour) + ":" + "0" + str(minute) + ":" + str(second)
    if second < 10 and minute < 10:
        zeit = str(hour) + ":" + "0" + str(minute) + ":" + "0" + str(second)
    updating_label1.text = zeit
    # Minuten- und Stundenpunkt setzen
    # Minuten
    xpos_min_neu = int(width/2 + 105*math.cos((minute-15)*math.pi/30))
    delta_min_x = xpos_min_neu - xpos_min
    xpos_min = xpos_min_neu
    ypos_min_neu = int(height/2 + 105*math.sin((minute-15)*math.pi/30))
    delta_min_y = ypos_min_neu - ypos_min
    ypos_min = ypos_min_neu
    circle_min.x = circle_min.x + delta_min_x
    circle_min.y = circle_min.y + delta_min_y
    # Stunden
    xpos_hour_neu = int(width/2 + int(105*math.cos((hour)*math.pi/6 + minute/2*math.pi/180 - math.pi/2)))
    delta_hour_x = xpos_hour_neu - xpos_hour
    xpos_hour = xpos_hour_neu
    ypos_hour_neu = int(height/2 + int(105*math.sin((hour)*math.pi/6 + minute/2*math.pi/180 - math.pi/2)))
    delta_hour_y = ypos_hour_neu - ypos_hour
    ypos_hour = ypos_hour_neu
    circle_hour.x = circle_hour.x + delta_hour_x
    circle_hour.y = circle_hour.y + delta_hour_y