# SPDX-FileCopyrightText : 2023 Detlef Gebhardt, written for CircuitPython
# SPDX-FileCopyrightText : Copyright (c) 2023 Detlef Gebhardt
# SPDX-Filename          : Earth-Clock
# SPDX-License-Identifier: GEBMEDIA
import time
import gc
import board
import busio
import displayio
import terminalio
from adafruit_display_text import label
from adafruit_display_shapes.roundrect import RoundRect
from adafruit_display_shapes.circle import Circle
import adafruit_imageload
from adafruit_ticks import ticks_ms
import math
import gc9a01
import my_qmi8658

# Alle verwendeten Ressourcen freigeben
displayio.release_displays()
# Display initialisieren
spi = busio.SPI(clock=board.LCD_CLK, MOSI=board.LCD_DIN)
display_bus = displayio.FourWire(spi, command=board.LCD_DC, chip_select=board.LCD_CS, reset=board.LCD_RST)
display = gc9a01.GC9A01(display_bus, width=240, height=240, backlight_pin=board.LCD_BL)
group1 = displayio.Group()
display.rotation = 90
display.brightness = 1

display.show(group1)

# Sensor initialisieren
sensor=my_qmi8658.QMI8658()

zeit = " Uhrzeit"
start = 0

image1, palette = adafruit_imageload.load(
    "/images/erde.bmp", bitmap=displayio.Bitmap, palette=displayio.Palette)
tile_grid1 = displayio.TileGrid(image1, pixel_shader=palette)
group1.append(tile_grid1)

# Rechteck mit abgerundeten Ecken
roundrect1 = RoundRect(60, 132, 120, 40, 10, fill=0x0, outline=0xffffff, stroke=3)
group1.append(roundrect1)

## create the label for time
updating_label1 = label.Label(
    font=terminalio.FONT, text=zeit, scale=2, color=0xffffff,
    line_spacing=1)
# set label position on the display and add label
updating_label1.anchor_point = (0, 0)
updating_label1.anchored_position = (70, 140)
group1.append(updating_label1)

while True:
    #read QMI8658
    reading=sensor.Read_XYZ()
    # Display wird um die y-Achse gekippt
    wert_y = (10)*reading[0]
    wert_x = (10)*reading[1]
    #print(wert_y,wert_x)
    
    if wert_y < -6:
        display.rotation = 0
        display.brightness = 1
        start = ticks_ms()  
    if wert_y >= -6 and wert_y <= 6 and wert_x < -6:
        display.rotation = 90
        display.brightness = 1
        start = ticks_ms()   
    if wert_y >= -6 and wert_y <= 6 and wert_x > 6:
        display.rotation = 270
        display.brightness = 1
        start = ticks_ms()
    if wert_y > 6:
        display.rotation = 180
        display.brightness = 1
        start = ticks_ms()
    # Display nach 3 sec abschalten
    if (ticks_ms() - start)/ 1000 > 3:
        display.brightness = 0
        start = 0
